==> devops-client-java-1.0.6-sources.jar: io/alauda/devops/java/client/models/V1alpha1ListIssuesOptionsFluent.java <==
package io.alauda.devops.java.client.models;

import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.Fluent;
import java.lang.String;
import java.lang.Boolean;

public interface V1alpha1ListIssuesOptionsFluent<A extends V1alpha1ListIssuesOptionsFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getIssuekey();
    public A withIssuekey(String issuekey);
    public Boolean hasIssuekey();
    public A withNewIssuekey(String arg1);
    public A withNewIssuekey(StringBuilder arg1);
    public A withNewIssuekey(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public String getOrderby();
    public A withOrderby(String orderby);
    public Boolean hasOrderby();
    public A withNewOrderby(String arg1);
    public A withNewOrderby(StringBuilder arg1);
    public A withNewOrderby(StringBuffer arg1);
    public Integer getPage();
    public A withPage(Integer page);
    public Boolean hasPage();
    public Integer getPagesize();
    public A withPagesize(Integer pagesize);
    public Boolean hasPagesize();
    public String getPriority();
    public A withPriority(String priority);
    public Boolean hasPriority();
    public A withNewPriority(String arg1);
    public A withNewPriority(StringBuilder arg1);
    public A withNewPriority(StringBuffer arg1);
    public String getProject();
    public A withProject(String project);
    public Boolean hasProject();
    public A withNewProject(String arg1);
    public A withNewProject(StringBuilder arg1);
    public A withNewProject(StringBuffer arg1);
    public String getSort();
    public A withSort(String sort);
    public Boolean hasSort();
    public A withNewSort(String arg1);
    public A withNewSort(StringBuilder arg1);
    public A withNewSort(StringBuffer arg1);
    public String getStatus();
    public A withStatus(String status);
    public Boolean hasStatus();
    public A withNewStatus(String arg1);
    public A withNewStatus(StringBuilder arg1);
    public A withNewStatus(StringBuffer arg1);
    public String getSummary();
    public A withSummary(String summary);
    public Boolean hasSummary();
    public A withNewSummary(String arg1);
    public A withNewSummary(StringBuilder arg1);
    public A withNewSummary(StringBuffer arg1);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);



}

==> devops-client-java-1.0.7.1-sources.jar: io/alauda/devops/java/client/models/V1alpha1ListIssuesOptionsFluent.java <==
package io.alauda.devops.java.client.models;

import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import io.alauda.devops.java.client.fluent.Predicate;

public interface V1alpha1ListIssuesOptionsFluent<A extends V1alpha1ListIssuesOptionsFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getIssuekey();
    public A withIssuekey(String issuekey);
    public Boolean hasIssuekey();
    public A withNewIssuekey(String arg1);
    public A withNewIssuekey(StringBuilder arg1);
    public A withNewIssuekey(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public String getOrderby();
    public A withOrderby(String orderby);
    public Boolean hasOrderby();
    public A withNewOrderby(String arg1);
    public A withNewOrderby(StringBuilder arg1);
    public A withNewOrderby(StringBuffer arg1);
    public Integer getPage();
    public A withPage(Integer page);
    public Boolean hasPage();
    public Integer getPagesize();
    public A withPagesize(Integer pagesize);
    public Boolean hasPagesize();
    public String getPriority();
    public A withPriority(String priority);
    public Boolean hasPriority();
    public A withNewPriority(String arg1);
    public A withNewPriority(StringBuilder arg1);
    public A withNewPriority(StringBuffer arg1);
    public String getProject();
    public A withProject(String project);
    public Boolean hasProject();
    public A withNewProject(String arg1);
    public A withNewProject(StringBuilder arg1);
    public A withNewProject(StringBuffer arg1);
    public A addToProjects(int index,String item);
    public A setToProjects(int index,String item);
    public A addToProjects(String... items);
    public A addAllToProjects(Collection<String> items);
    public A removeFromProjects(String... items);
    public A removeAllFromProjects(Collection<String> items);
    public List<String> getProjects();
    public String getProject(int index);
    public String getFirstProject();
    public String getLastProject();
    public String getMatchingProject(io.alauda.devops.java.client.fluent.Predicate<String> predicate);
    public Boolean hasMatchingProject(io.alauda.devops.java.client.fluent.Predicate<String> predicate);
    public A withProjects(List<String> projects);
    public A withProjects(String... projects);
    public Boolean hasProjects();
    public A addNewProject(String arg1);
    public A addNewProject(StringBuilder arg1);
    public A addNewProject(StringBuffer arg1);
    public String getSort();
    public A withSort(String sort);
    public Boolean hasSort();
    public A withNewSort(String arg1);
    public A withNewSort(StringBuilder arg1);
    public A withNewSort(StringBuffer arg1);
    public String getStatus();
    public A withStatus(String status);
    public Boolean hasStatus();
    public A withNewStatus(String arg1);
    public A withNewStatus(StringBuilder arg1);
    public A withNewStatus(StringBuffer arg1);
    public String getSummary();
    public A withSummary(String summary);
    public Boolean hasSummary();
    public A withNewSummary(String arg1);
    public A withNewSummary(StringBuilder arg1);
    public A withNewSummary(StringBuffer arg1);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);



}
